@@ -757,9 +757,11 @@ def parse_config(scn_cfg, qmin, installdir):  # FIXME: pylint: disable=too-many-
     trust_anchor_files = {}
     negative_ta_list = []
     stub_addr = None
+    stub_name = "k.root-servers.net"
     override_timestamp = None
     forward_addr = None
-
+    do_ip6 = True
+    do_ip4 = True
     features = {}
     feature_list_delimiter = ';'
     feature_pair_delimiter = '='
@@ -798,6 +800,8 @@ def parse_config(scn_cfg, qmin, installdir):  # FIXME: pylint: disable=too-many-
             override_timestamp = calendar.timegm(override_date)
         elif k == 'stub-addr':
             stub_addr = v.strip('"\'')
+        elif k == 'stub-name':
+            stub_name = v
         elif k == 'features':
             feature_list = v.split(feature_list_delimiter)
             try:
@@ -827,6 +831,10 @@ def parse_config(scn_cfg, qmin, installdir):  # FIXME: pylint: disable=too-many-
             sockfamily = socket.AF_INET6
         elif k == 'forward-addr':  # currently forwards everything
             forward_addr = v.strip('"\'')
+        elif k == 'do-ip4':
+            do_ip4 = str2bool(v)
+        elif k == 'do-ip6':
+            do_ip6 = str2bool(v)
         else:
             raise NotImplementedError('unsupported CONFIG key "%s"' % k)
 
@@ -840,9 +848,12 @@ def parse_config(scn_cfg, qmin, installdir):  # FIXME: pylint: disable=too-many-
         "TRUST_ANCHORS": trust_anchor_list,
         "TRUST_ANCHOR_FILES": trust_anchor_files,
         "FORWARD_ADDR": forward_addr,
+        "DO_IP6": str(do_ip6).lower(),
+        "DO_IP4": str(do_ip4).lower(),
     }
     if stub_addr:
         ctx['ROOT_ADDR'] = stub_addr
+        ctx['ROOT_NAME'] = stub_name
         # determine and verify socket family for specified root address
         gai = socket.getaddrinfo(stub_addr, 53, sockfamily, 0,
                                  socket.IPPROTO_UDP, socket.AI_NUMERICHOST)
